============
Installation
============

The preferred way to install ``django-bootstrap5`` is ``pip``::

    $ pip install django-bootstrap5

Alternatively, you can install download or clone this repo and install from its folder with::

    $ pip install -e .

In your project, you should add ``django-bootstrap5`` to your ``requirements.txt``.

Be sure to use ``virtualenv`` if you develop python projects.

Add to INSTALLED_APPS in your ``settings.py``:

   ``'django_bootstrap5',``

After installation, the :doc:`quickstart` will get you on your way to using ``django-bootstrap5``.
